@@ -44,6 +44,8 @@ _LOGGER = logging.getLogger(__name__)
 
 def fill_package_digests(generated_project: "Project") -> "Project":
     """Temporary fill package digests stated in Pipfile.lock."""
+    if generated_project.pipfile_lock is None:
+        raise ValueError("Generated project PipfileLock is not set.")
     for package_version in chain(generated_project.pipfile_lock.packages, generated_project.pipfile_lock.dev_packages):
         if package_version.hashes:
             # Already filled from the last run.
