@@ -188,7 +188,10 @@ class _PipfileBase:
         requirements_file = self.meta.to_requirements_index_conf()
 
         for package_version in self.packages.packages.values() if not develop else self.dev_packages.packages.values():
-            requirements_file += f"{package_version.name}{package_version.version}"
+            if package_version.version:
+                requirements_file += f"{package_version.name}{package_version.version}\n"
+            else:
+                requirements_file += f"{package_version.name}\n"
 
         return requirements_file
 
@@ -323,7 +326,7 @@ class ThothPipfileSection:
     def from_dict(cls, dict_: Dict[str, Any]) -> "ThothPipfileSection":
         """Convert Thoth specific section in Pipfile to a dictionary representation."""
         dict_ = dict(dict_)
-        allow_prereleases = dict_.pop("allow_prereleases", {})
+        allow_prereleases = dict_.pop("allow_prereleases") or {}
         disable_index_adjustment = dict_.pop("disable_index_adjustment", False)
 
         if dict_:
@@ -333,11 +336,13 @@ class ThothPipfileSection:
             _LOGGER.warning(
                 "allow_prereleases expected to be a dictionary, but got %r instead - ignoring", type(allow_prereleases)
             )
+            allow_prereleases = {}
         if not isinstance(disable_index_adjustment, bool):
             _LOGGER.warning(
                 "disable_index_adjustment expected to be a boolean, but got %r instead - ignoring",
                 type(disable_index_adjustment),
             )
+            disable_index_adjustment = False
 
         for k, v in list(allow_prereleases.items()):
             if not isinstance(k, str) or not k:
